import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
// import { any } from '../../services/fitness-data.service';
// import { any } from '../../models/workout.model';
// import { any } from '../../models/health.model';
// import { any } from '../../models/community.model';

@Component({
  selector: 'app-tab1',
  templateUrl: 'tab1.page.html',
  styleUrls: ['tab1.page.scss'],
  standalone: false,
})
export class Tab1Page {
  // 用户数据
  userData = {
    name: '张伟',
    avatar: 'assets/avatars/1.jpg',
    level: '黄金会员'
  };

  // 时间相关问候语
  timeBasedGreeting = this.getTimeBasedGreeting();
  dailyProgress = 65;
  unreadNotifications = 3;
  hasNewMessage = true;
  todaySteps = 8432;

  // 推荐训练计划
  recommendedPrograms: any[] = [
    {
      id: 'p1',
      name: '晨间唤醒训练',
      coverImage: 'assets/workouts/morning.jpg',
      duration: 15,
      calories: 120,
      difficulty: '初级',
      completionRate: 0.4,
      description: '适合清晨进行的低强度有氧运动',
      isTodayRecommended: true
    },
    // 更多训练计划...
  ];

  // 健康指标
  anys: any[] = [
    { type: 'heart', value: 72, unit: 'bpm', trend: 'down' },
    { type: 'steps', value: 8432, unit: '步', trend: 'up' },
    { type: 'sleep', value: 6.5, unit: '小时', trend: 'same' },
    { type: 'weight', value: 68.5, unit: 'kg', trend: 'down' }
  ];

  // 快捷操作
  quickActions = [
    { id: 'scan', icon: 'barcode', label: '营养扫描', color: 'success' },
    { id: 'challenge', icon: 'trophy', label: '每日挑战', color: 'warning' },
    { id: 'record', icon: 'add-circle', label: '手动记录', color: 'tertiary' },
    { id: 'community', icon: 'people', label: '发现好友', color: 'danger' }
  ];

  // 社区动态
  communityPosts: any[] = [
    {
      id: 'post1',
      user: { name: '健身达人', avatar: 'assets/avatars/2.jpg' },
      content: '刚刚完成了30天腹肌挑战，看看我的变化！',
      likes: 24,
      timestamp: new Date(Date.now() - 3600000 * 2),
      images: ['assets/posts/1.jpg']
    },
    // 更多帖子...
  ];

  constructor(
    // private fitnessData: any,
    private modalCtrl: ModalController
  ) {}

  ngOnInit() {
    this.loadData();
  }

  async loadData() {
    // 从服务加载数据
    // const [programs, metrics] = await Promise.all([
      // this.fitnessData.getRecommendedPrograms(),
      // this.fitnessData.getanys()
    // ]);

    // this.recommendedPrograms = programs;
    // this.anys = metrics;
  }

  getTimeBasedGreeting(): string {
    const hour = new Date().getHours();
    if (hour < 5) return '深夜好';
    if (hour < 11) return '早上好';
    if (hour < 14) return '中午好';
    if (hour < 18) return '下午好';
    return '晚上好';
  }

  startWorkout(program?: any) {
    // 导航到训练页面
    console.log('开始训练:', program?.name || '自由训练');
  }

  onMetricSelect(metric: any) {
    // 显示指标详情
    console.log('选择指标:', metric.type);
  }

  handleQuickAction(action: any) {
    switch(action.id) {
      case 'scan':
        this.openBarcodeScanner();
        break;
      // 其他操作处理...
    }
  }

  async openBarcodeScanner() {
    // 实现扫码功能
    console.log('打开营养扫描');
  }

  likePost(post: any) {
    // 点赞逻辑
    post.likes++;
  }

  openPostDetail(post: any) {
    // 打开帖子详情
    console.log('查看帖子:', post.id);
  }

  openNotifications() {
    // 打开通知中心
    console.log('打开通知');
  }

  openProfile() {
    // 打开个人资料
    console.log('打开个人资料');
  }

  openCoach() {
    // 与虚拟教练互动
    console.log('联系教练');
  }

  segmentChanged(ev: any) {
    // 处理分段控件变化
    console.log('Segment changed', ev.detail.value);
  }
}
